@@ -91,11 +91,9 @@ static gboolean cupboard_icon_clicked(TangleButton *tanglebutton, gpointer data)
 	else //if (strncmp(easy,"a",1)==0) //it is safer to use advanced if this is not clear
 		chum_set_easy_game(FALSE); //a=advanced
 
+	themeselection_load(data); //This doesn't do actual loading. It happens after animation is completed.
 	themeselection_start_theme(theme_name,atoi(variation_name),jammo_get_actor_by_id("cupboard-view"));
 
-	//This is hack.  FIXME: for some reason we can't just call this.
-	g_timeout_add(100,themeselection_load,data);
-
 	g_free(filename);
 	return FALSE;
 }
@@ -245,10 +243,38 @@ static gboolean cupboard_song_icon_clicked(TangleButton *tanglebutton, gpointer
 
 
 
+//Read first row of file:
+//Caller must handle freeing.
+static gchar* give_first_row_of_file(gchar* filename){
+	printf("give_first_row_of_file: filename='%s'\n",filename);
+	FILE *ifp;
+	ifp = fopen(filename, "r");
+	g_return_val_if_fail(ifp != NULL, FALSE);
+
+	int bytes_read;
+	size_t nbytes = 200;
+	char *my_string;
+	my_string = (char *) malloc (nbytes + 1);
+
+	bytes_read = getline (&my_string, &nbytes, ifp);
+
+
+	char* row = malloc (bytes_read + 1);
+	strncpy(row, my_string, strlen(my_string)-1); //throw end-of-line away
+	row[strlen(my_string)-1]='\0';                //Add string terminator
+
+	g_free(my_string);
+	fclose(ifp);
+
+	printf("give_first_row_of_file: will return='%s'\n",row);
+	return row;
+}
+
+
 /*
 This will also check and load icons for savings.
 */
-void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+static void load_icons (JammoMentor* mentor, const gchar* speech, gpointer sequencer){
 	//When ending composing started from cupboard, we come back to this function.
 	//Set easy/advanced state back to what it was before loading compositions.
 	if (previous_game_mode==0)
@@ -277,7 +303,9 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 	for (l = files; l; l = l->next)
 		{
 		//printf("readed '%s'\n",(char*)l->data);
-	
+		ClutterActor* icon;
+
+		#ifdef old_way_to_load_icons
 		//We need copy because strtok overwrite.
 		gchar *filename; 
 		filename = g_strdup_printf("%s",(gchar*)l->data);
@@ -289,7 +317,6 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 		char* variation_name = strtok(NULL, "+");
 		char* easy  = strtok(NULL, "+");
 
-		ClutterActor* icon;
 		gchar* icon_filename;
 		if (theme_name == NULL || variation_name == NULL || easy == NULL) {
 			g_free(filename);
@@ -313,17 +340,24 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 			g_free(filename);
 			break;
 		}
+		#endif
 
 
-		icon = tangle_button_new_with_background_actors(clutter_texture_new_from_file(icon_filename, NULL), clutter_texture_new_from_file(icon_filename, NULL));
-		g_object_set(icon,"depth-position", -1, "width", 80.0, "height", 80.0, "x", 30.0,  "y", 7+counter1*94.0, NULL);
-		
-		clutter_container_add(CLUTTER_CONTAINER(container_for_saved_icons), icon, NULL);
-		clutter_actor_set_reactive(icon,TRUE);
-		g_signal_connect_data(icon, "clicked", G_CALLBACK (cupboard_icon_clicked),l->data,(GClosureNotify) g_free,0);
-		counter1++;
-		
-		g_free(filename);
+		gchar* icon_filename = give_first_row_of_file((gchar*)l->data);
+		printf("got icon_filename='%s'\n", icon_filename);
+
+		ClutterActor* image = clutter_texture_new_from_file(icon_filename, NULL);
+		if (image) { //If filename is missing, suppose whole file is corrupted and do not add it
+			icon = tangle_button_new_with_background_actor(image);
+			g_object_set(icon,"depth-position", -1, "width", 80.0, "height", 80.0, "x", 30.0,  "y", 7+counter1*94.0, NULL);
+
+			clutter_container_add(CLUTTER_CONTAINER(container_for_saved_icons), icon, NULL);
+			clutter_actor_set_reactive(icon,TRUE);
+			g_signal_connect_data(icon, "clicked", G_CALLBACK (cupboard_icon_clicked),l->data,(GClosureNotify) g_free,0);
+			counter1++;
+		}
+
+		g_free(icon_filename);
 		}
 
 	
@@ -345,7 +379,8 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 		//printf("name = '%s'\n",name);
 		char* name1 = &name[strlen(filepath1)+1];
 		//printf("name1 = '%s'\n",name1);
-	
+		if (strlen(name1)<4 || strlen(name1)>20)
+			continue;
 		char* name2 = malloc (20);
 		strncpy( name2, name1,strlen(name1)-4);
 		name2[strlen(name1)-4]='\0';
@@ -354,19 +389,19 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 		gchar* icon_filename=g_strdup_printf("%s/songs/%s/icon.png",DATA_DIR,name2);
 		//printf("looking for '%s'\n",icon_filename);
 		
-		icon = tangle_button_new_with_background_actors(clutter_texture_new_from_file(icon_filename, NULL), clutter_texture_new_from_file(icon_filename, NULL));
+		ClutterActor* image = clutter_texture_new_from_file(icon_filename, NULL);
+		if (image) {
+			icon = tangle_button_new_with_background_actor(image);
+			g_object_set(icon,"depth-position", -1, "width", 80.0, "height", 80.0, "x", 197.0,  "y", 7+counter2*94.0, NULL);
+			clutter_container_add(CLUTTER_CONTAINER(container_for_saved_icons), icon, NULL);
+			clutter_actor_set_reactive(icon,TRUE);
+			char* name_for_callback = malloc (20);
+			strcpy(name_for_callback,name2);
+			g_signal_connect (icon, "clicked", G_CALLBACK (cupboard_song_icon_clicked),name_for_callback);
+			counter2++;
+			}
 		g_free(icon_filename);
-
-		g_object_set(icon,"depth-position", -1, "width", 80.0, "height", 80.0, "x", 197.0,  "y", 7+counter2*94.0, NULL);
-
-		clutter_container_add(CLUTTER_CONTAINER(container_for_saved_icons), icon, NULL);
-		
-		clutter_actor_set_reactive(icon,TRUE);
-		char* name_for_callback = malloc (20);
-		strcpy(name_for_callback,name2);
-		g_signal_connect (icon, "clicked", G_CALLBACK (cupboard_song_icon_clicked),name_for_callback);
 		g_free(name2);
-		counter2++;
 		}
 		
 	g_list_foreach(files, (GFunc)g_free, NULL);
@@ -395,10 +430,25 @@ void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar
 	g_object_set(scrolling_actor,"depth-position", -1,NULL);
 	clutter_container_add_actor(CLUTTER_CONTAINER(jammo_get_actor_by_id("cupboard-view")), scrolling_actor);
 	
-	cupboard_door_clicked(NULL,NULL,NULL,NULL);
+	//cupboard_door_clicked(NULL,NULL,NULL,NULL);
 }
 
+static void mentor_over(JammoMentor* mentor, const gchar* speech, gpointer sequencer){
+cupboard_door_clicked(NULL,NULL,NULL,NULL);
+}
+
+//This is callback for json.
+void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	printf("cupboard_start_cupboard\n");
+	load_icons(NULL,NULL,NULL);
+	jammo_mentor_speak_once_with_callback(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_cupboard_welcome_fi.ogg",mentor_over,NULL);
+	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_cupboard_welcome_fi.ogg");
+}
+
+//This is callback for json.
 void cupboard_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	printf("cupboard_door_clicked\n");
+	jammo_mentor_shut_up(jammo_mentor_get_default());
 	ClutterActor* actor;
 	ClutterActor* actor2;
 	ClutterAnimation* animation;
