@@ -139,6 +139,39 @@ static void jammo_track_view_get_preferred_height(TangleActor* actor, gfloat for
 	}
 }
 
+static ClutterActor* do_grid(gfloat grid_size_x, gfloat grid_size_y, gfloat full_width, gint number_of_grids){
+	ClutterActor* grid = tangle_widget_new();
+	ClutterColor black = { 0,0,0, 255 };
+	ClutterColor grey = { 0,0,0, 50 };
+	int border_width_horizontal = 3;
+	int border_width_vertical = 1;
+
+	ClutterActor* top = clutter_rectangle_new_with_color (&black);
+	clutter_rectangle_set_border_color(CLUTTER_RECTANGLE(top),&black);
+	clutter_rectangle_set_border_width(CLUTTER_RECTANGLE(top),border_width_horizontal);
+	clutter_actor_set_size (top,full_width, border_width_horizontal);
+	clutter_actor_set_position (top,0,0);
+	clutter_container_add_actor (CLUTTER_CONTAINER (grid), top);
+
+	ClutterActor* bottom = clutter_rectangle_new_with_color (&black);
+	clutter_rectangle_set_border_color(CLUTTER_RECTANGLE(bottom),&black);
+	clutter_rectangle_set_border_width(CLUTTER_RECTANGLE(bottom),border_width_horizontal);
+	clutter_actor_set_size (bottom,full_width, border_width_horizontal);
+	clutter_actor_set_position (bottom,0,grid_size_y);
+	clutter_container_add_actor (CLUTTER_CONTAINER (grid), bottom);
+
+	int i;
+	for (i=0;i<number_of_grids;i++){
+		ClutterActor* bar = clutter_rectangle_new_with_color (&grey);
+		clutter_rectangle_set_border_color(CLUTTER_RECTANGLE(bar),&grey);
+		clutter_rectangle_set_border_width(CLUTTER_RECTANGLE(bar),border_width_vertical);
+		clutter_actor_set_size (bar, border_width_vertical,grid_size_y);
+		clutter_actor_set_position (bar,grid_size_x*i,0);
+		clutter_container_add_actor (CLUTTER_CONTAINER (grid), bar);
+	}
+
+	return grid;
+}
 static void jammo_track_view_allocate_wrapped(TangleWrapperActor* wrapper_actor, ClutterActor* wrapped, const ClutterActorBox* box, ClutterAllocationFlags flags) {
 	JammoTrackView* track_view;
 	ClutterActor* grid;
@@ -151,6 +184,12 @@ static void jammo_track_view_allocate_wrapped(TangleWrapperActor* wrapper_actor,
 
 	if (track_view->priv->line_every_nth_slot) {
 		grid = tangle_grid_new(track_view->priv->real_slot_size * track_view->priv->line_every_nth_slot - (1.0 / track_view->priv->n_slots), box->y2 - box->y1 - 1.0);
+/*
+		grid = do_grid(track_view->priv->real_slot_size * track_view->priv->line_every_nth_slot - (1.0 / track_view->priv->n_slots), //width of one grid
+						76, //height of the grid
+						track_view->priv->n_slots * track_view->priv->real_slot_size, //     full width of area
+						track_view->priv->n_slots / track_view->priv->line_every_nth_slot +1 ); //number of needed grids
+*/
 		tangle_widget_set_background_actor(TANGLE_WIDGET(wrapped), grid);
 	} else {
 		tangle_widget_set_background_actor(TANGLE_WIDGET(wrapped), NULL);
