@@ -37,7 +37,9 @@
 #include <clutter/x11/clutter-x11.h>
 #endif
 
-
+//This is defined in welcome.c and will executed if nothing happens after 10 seconds
+void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties);
+static gboolean door_timeouts(gpointer data);
 static const char* search_path = "/opt/jammo";
 
 /*
@@ -280,6 +282,7 @@ int main(int argc, char** argv) {
 		start_communitymenu();
 	}
 	
+	g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
 	clutter_main();
 
 	g_object_unref(stage);
@@ -293,7 +296,11 @@ int main(int argc, char** argv) {
 
 	return 0;
 }
-
+static gboolean door_timeouts(gpointer data){
+printf("door_timeouts\n");
+welcome_door_clicked(NULL,NULL,NULL,NULL);
+return FALSE;
+}
 
 
 //FIXME: this is copy-pasted from singing-game (solo/duetto and language-selection uses same kind of mechanism)
