@@ -27,7 +27,17 @@ static void finalize_welcome(void) {
 	}
 }
 
+
+/*
+If user doesn't click door, there are timeout. Timeout calls welcome_door_clicked, but action==NULL.
+All this hazzling is needed because user can click (or double click) very same time than timeout triggers.
+*/
+static gboolean door_is_opening = FALSE; //Or opened already.
 void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	if (door_is_opening && action == NULL)
+		return;
+
+	door_is_opening = TRUE;
 	ClutterActor* actor;
 	ClutterAnimation* animation;
 	ClutterTimeline* timeline;
@@ -63,3 +73,4 @@ void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *tr
 	clutter_container_add_actor (CLUTTER_CONTAINER (actor), version_label);
 
 }
+
